@@ -3,6 +3,7 @@
  * See LICENSE file in root directory for full license.
  */
 import sourcemaps from "rollup-plugin-sourcemaps"
+import packageInfo from "./package.json"
 
 /**
  * Define the output configuration.
@@ -13,14 +14,14 @@ function config(ext) {
     return {
         input: "src/index.js",
         output: {
+            exports: ext === ".mjs" ? undefined : "named",
             file: `index${ext}`,
             format: ext === ".mjs" ? "es" : "cjs",
             sourcemap: true,
-            banner:
-                "/*! @author Toru Nagashima <https://github.com/mysticatea> */",
+            banner: "/*! @author Toru Nagashima <https://github.com/mysticatea> */",
         },
         plugins: [sourcemaps()],
-        external: Object.keys(require("./package.json").dependencies),
+        external: Object.keys(packageInfo.dependencies),
     }
 }
 
